//  ISExpandableTextCell.m
//  ExpandableTextCell
//
//  Created by Simon Liu on 17/6/8.
//  Copyright © 2017年 xzliu. All rights reserved.
//


#import "ISExpandableTextCell.h"

#define kPadding 5

#define LEFTTEXT_WIDTH 120
#define TEXT_WIDTH 100

@interface ISExpandableTextCell ()<UITextViewDelegate>
@property (nonatomic, strong) ISCellTextView *textView;
@property (nonatomic, strong) ISCellTextView *leftTextView;

@end

#pragma mark -

@implementation ISExpandableTextCell

- (id)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self.contentView addSubview:self.textView];
        [self.contentView addSubview:self.leftTextView];

    }
    return self;
}

- (ISCellTextView *)textView
{
    if (_textView == nil) {
//        CGRect cellFrame = self.contentView.bounds;
        CGRect cellFrame = CGRectMake(TEXT_WIDTH, 0, self.contentView.frame.size.width-TEXT_WIDTH-5, self.contentView.frame.size.height);

        cellFrame.origin.y += kPadding;
        cellFrame.size.height -= kPadding;
        
        _textView = [[ISCellTextView alloc] initWithFrame:cellFrame];
        _textView.delegate = self;
        _textView.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
        _textView.backgroundColor = [UIColor clearColor];
        _textView.font = [UIFont systemFontOfSize:14.0f];
        _textView.scrollEnabled = NO;
        _textView.showsVerticalScrollIndicator = NO;
        _textView.showsHorizontalScrollIndicator = NO;
        // textView.contentInset = UIEdgeInsetsZero;
    }
    return _textView;
}


- (ISCellTextView *)leftTextView
{
    if (_leftTextView == nil) {
        //        CGRect cellFrame = self.contentView.bounds;
        CGRect cellFrame = CGRectMake(10, 0, 120, self.contentView.frame.size.height);
        
        cellFrame.origin.y += kPadding;
        cellFrame.size.height -= kPadding;
        
        _leftTextView = [[ISCellTextView alloc] initWithFrame:cellFrame];
        _leftTextView.delegate = self;
        _leftTextView.editable = NO;
        _leftTextView.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
        _leftTextView.backgroundColor = [UIColor clearColor];
        _leftTextView.font = [UIFont systemFontOfSize:12.0f];
        _leftTextView.textColor = [UIColor colorWithRed:66.0f/255.0f green:178.0f/255.0f blue:249.0f/255.0f alpha:1];
        _leftTextView.scrollEnabled = NO;
        _leftTextView.showsVerticalScrollIndicator = NO;
        _leftTextView.showsHorizontalScrollIndicator = NO;
        // textView.contentInset = UIEdgeInsetsZero;
    }
    return _leftTextView;
}


- (void)setText:(NSString *)text
{
    _text = text;
    // update the UI
    self.textView.text = text;
    
}

- (void)setLeftText:(NSString *)leftText
{
    _leftText = leftText;
    self.leftTextView.text = leftText;
}

- (CGFloat)cellHeight
{
    return [self.textView sizeThatFits:CGSizeMake(self.textView.frame.size.width, FLT_MAX)].height + kPadding * 2;
}


#pragma mark - Text View Delegate

- (BOOL)textViewShouldBeginEditing:(UITextView *)textView
{
    // make sure the cell is at the top
    [self.expandableTableView scrollToRowAtIndexPath:[self.expandableTableView indexPathForCell:self]
                                    atScrollPosition:UITableViewScrollPositionTop
                                            animated:YES];
    
    return YES;
}



- (void)textViewDidChange:(UITextView *)theTextView
{
    if ([self.expandableTableView.delegate conformsToProtocol:@protocol(ISExpandableTableViewDelegate)])
    {
        
        id<ISExpandableTableViewDelegate> delegate = (id<ISExpandableTableViewDelegate>)self.expandableTableView.delegate;
        NSIndexPath *indexPath = [self.expandableTableView indexPathForCell:self];
        
        // update the text
        _text = self.textView.text;
        
        [delegate tableView:self.expandableTableView
                updatedText:_text
                atIndexPath:indexPath];
        
        CGFloat newHeight = [self cellHeight];
        CGFloat oldHeight = [delegate tableView:self.expandableTableView heightForRowAtIndexPath:indexPath];
        if (fabs(newHeight - oldHeight) > 0.01) {
            
            // update the height
            if ([delegate respondsToSelector:@selector(tableView:updatedHeight:atIndexPath:)]) {
                [delegate tableView:self.expandableTableView
                      updatedHeight:newHeight
                        atIndexPath:indexPath];
            }
            
            // refresh the table without closing the keyboard
            [self.expandableTableView beginUpdates];
            [self.expandableTableView endUpdates];
        }
    }else
        {
            NSLog(@"POSITION CONTAINS");
        }
}
- (void)prepareForReuse

{
    
    [super prepareForReuse];
    
}
@end

#pragma mark -

@implementation UITableView (ISExpandableTextCell)

- (ISExpandableTextCell *)expandableTextCellWithId:(NSString *)cellId
{
    ISExpandableTextCell *cell = [self dequeueReusableCellWithIdentifier:cellId];
    if (cell == nil) {
        cell = [[ISExpandableTextCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellId];
        cell.selectionStyle = UITableViewCellSelectionStyleNone;
        cell.expandableTableView = self;
        
    }
    return cell;
}


@end

