//
//  ISViewController.m
//  ExpandableTextCell
//
//  Created by Simon Liu on 17/6/8.
//  Copyright © 2017年 xzliu. All rights reserved.
//

#import "ISViewController.h"
#import "ISExpandableTextCell.h"
#import <ISDrivingLicensePreviewSDK/ISDrivingLicensePreviewSDK.h>
#import <ISOpenSDKFoundation/ISOpenSDKFoundation.h>
#import "ISZoomScrollView.h"

#define IS_DEVICE_HEIGHT    [[UIScreen mainScreen] bounds].size.height
#define IS_DEVICE_WIDTH     [[UIScreen mainScreen] bounds].size.width

#define COLOR_WITH_HEX(hexValue) [UIColor colorWithRed:((float)((hexValue & 0xFF0000) >> 16)) / 255.0 green:((float)((hexValue & 0xFF00) >> 8)) / 255.0 blue:((float)(hexValue & 0xFF)) / 255.0 alpha:1.0f]


@interface ISViewController ()<ISExpandableTableViewDelegate>
{
    CGFloat _cellHeight[1000];
    BOOL _loadImageBOOL;
    
    NSArray *_infoImageArray;
    NSDictionary *_OCRDict;
    NSArray *_OCRArray;

}

@property (nonatomic, strong) NSMutableArray *cellData;
@property (nonatomic, strong) NSMutableArray *cellDataKey;

@property (strong, nonatomic) NSDictionary *infoDic;
@property (strong, nonatomic) UIImage *originImage;
@property (strong, nonatomic) UIImage *headImage;
@property (strong, nonatomic) UIImage *typeImage;
@property (strong, nonatomic) ISZoomScrollView *zoomScrollView ;

@end

@implementation ISViewController

- (instancetype)initWithDictionary:(NSDictionary *)info loadImageBool:(BOOL)loadImageBOOL
{
    self = [super init];
    if (self != nil) {
        self.originImage = [info valueForKey:kOpenSDKCardResultTypeImage];
        self.infoDic = [info valueForKey:kOpenSDKCardResultTypeCardItemInfo];
        self.typeImage = [info valueForKey:kOpenSDKCardResultTypeOriginImage];
        _loadImageBOOL=loadImageBOOL;

    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.navigationItem.title = @"驾驶证识别结果";
    //字体颜色
    self.navigationController.navigationBar.tintColor = [UIColor grayColor];
    self.navigationController.navigationBar.backgroundColor = [UIColor whiteColor];
    self.tableView.backgroundColor = [UIColor colorWithRed:241.0/255.0 green:241.0/255.0 blue:241.0/255.0 alpha:1];
    self.tableView.separatorColor =[UIColor colorWithRed:241.0/255.0 green:241.0/255.0 blue:241.0/255.0 alpha:1];
    self.tableView.separatorInset = UIEdgeInsetsMake(0, 15, 0, 15);//分割线缩进 两端距离
    
    if (_loadImageBOOL==NO) {
        _infoImageArray = [[NSArray alloc] init];
    }else{
        _infoImageArray = @[self.originImage,self.typeImage];
        
    }
    
    _OCRDict = @{
                    kDrivingCardItemIDNumber:@"驾驶证号",
                    kDrivingCardItemName:@"姓名",
                    kDrivingCardItemSex:@"性别",
                    kDrivingCardItemNationality:@"国籍",
                    kDrivingCardItemAddress:@"地址",
                    kDrivingCardItemBirthDay:@"出生日期",
                    kDrivingCardItemIssueDate:@"初次申领日期",
                    kDrivingCardItemDriveType:@"准驾车型",
                    kDrivingCardItemValidFrom:@"有效起始日期",
                    kDrivingCardItemValidFor:@"截止日期",
                    kDrivingCardItemValidity:@"有效期限",
                    };
    _OCRArray = @[
                     kDrivingCardItemIDNumber,
                     kDrivingCardItemName,
                     kDrivingCardItemSex,
                     kDrivingCardItemNationality,
                     kDrivingCardItemAddress,
                     kDrivingCardItemBirthDay,
                     kDrivingCardItemIssueDate,
                     kDrivingCardItemDriveType,
                     kDrivingCardItemValidFrom,
                     kDrivingCardItemValidFor,
                     kDrivingCardItemValidity,
                     ];

    self.cellData =[[NSMutableArray alloc] init];
    self.cellDataKey =[[NSMutableArray alloc] init];


        for (int i = 0 ; i < _OCRArray.count ; i ++)
        {
            NSString *OCR_String = _OCRArray[i];
            NSString *OCR_Key = _OCRDict[OCR_String];
            NSString *OCR_Value = self.infoDic[OCR_String];
            if (OCR_Value.length != 0) {
                [self.cellData addObject:OCR_Value];
                [self.cellDataKey addObject:OCR_Key];

            }
        }
    
    UITapGestureRecognizer * tapGesture = [[UITapGestureRecognizer alloc]initWithTarget:self action:@selector(dismissKeyBoard)];
    tapGesture.cancelsTouchesInView = NO;
    [self.tableView addGestureRecognizer:tapGesture];
    
    UIBarButtonItem *leftBarItem =  [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@"IS_Back"] style:UIBarButtonItemStyleDone target:self action:@selector(clickLeftBarButtonItem)];
    self.navigationItem.leftBarButtonItem = leftBarItem;
    
    UIView *header = [[UIView alloc] initWithFrame:CGRectMake(0, 0, IS_DEVICE_WIDTH, IS_DEVICE_HEIGHT*2/7)];
    [self setUpZoomScrollView:header];
    // 设置header
    self.tableView.tableHeaderView = header;
}

- (void)setUpZoomScrollView:(UIView *)addView
{
    self.zoomScrollView = [ISZoomScrollView roundScrollViewWithFrame:addView.frame imageArr:_infoImageArray timerWithTimeInterval:5 imageClick:^(NSInteger imageIndex) {
    }];
    [addView addSubview:self.zoomScrollView];
}

- (void)clickLeftBarButtonItem
{
    [self.zoomScrollView removeFromSuperview];
    [self dismissViewControllerAnimated:YES completion:nil];

}

-(void)dismissKeyBoard{
    [self.view endEditing:YES];
}

#pragma mark - Table View Data Source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.cellData.count;

}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSString *CellIdentifier = [NSString stringWithFormat:@"Cell%ld%ld", (long)[indexPath section], (long)[indexPath row]];//以indexPath来唯一确定cell
    ISExpandableTextCell *cell = [tableView expandableTextCellWithId:CellIdentifier];
    cell.leftTextView.text = self.cellDataKey[indexPath.row];
    cell.textView.text =[self.cellData objectAtIndex:indexPath.row];
    
    return cell;
}


#pragma mark - Table View Delegate
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSString* text = self.cellData[indexPath.row];
    CGSize constraint = CGSizeMake(self.view.frame.size.width-135, MAXFLOAT);
    
    NSAttributedString* attributedText = [[NSAttributedString alloc]initWithString:text attributes:@{NSFontAttributeName:[UIFont systemFontOfSize:14]}];
    
    CGRect rect = [attributedText boundingRectWithSize:constraint options:NSStringDrawingUsesLineFragmentOrigin context:nil];
    
    CGSize size = rect.size;
    
    CGFloat height = MAX(size.height+26.5, _cellHeight[indexPath.row]);
    
    return height;
}

- (void)tableView:(UITableView *)tableView updatedHeight:(CGFloat)height atIndexPath:(NSIndexPath *)indexPath
{
    _cellHeight[indexPath.row] = height;

}

- (void)tableView:(UITableView *)tableView updatedText:(NSString *)text atIndexPath:(NSIndexPath *)indexPath
{
    [_cellData replaceObjectAtIndex:indexPath.row withObject:text];

}


@end
