//
//  ISDrivingCardResultViewController.m
//  ISDrivingCardCameraPreview
//
//  Created by 汪凯 on 15/11/13.
//  Copyright © 2015年 汪凯. All rights reserved.
//

#import "ISDrivingCardResultViewController.h"
#import <ISDrivingLicensePreviewSDK/ISDrivingLicensePreviewSDK.h>

#define UIColorFromRGB(rgbValue) \
[UIColor \
colorWithRed:((float)((rgbValue & 0xFF0000) >> 16))/255.0 \
green:((float)((rgbValue & 0x00FF00) >> 8))/255.0 \
blue:((float)(rgbValue & 0x0000FF))/255.0 \
alpha:1.0]

@implementation ISDrivingCardResultItem

-(id) init
{
    self = [super init];
    if (self) {
        _typeText = nil;
        _resultText = nil;
        _numberOfline = 1;
    }
    return self;
}

@end

@interface ISDrivingCardResultViewController ()<UITableViewDataSource, UITableViewDelegate>

@property (weak, nonatomic) IBOutlet UIImageView *bgImageView;

@property (strong, nonatomic) IBOutlet UITableView *tableView;
@property (strong, nonatomic) IBOutlet UIButton *doneButton;

@property (strong, nonatomic) UILabel *titleLabel;
@property (strong, nonatomic) IBOutlet UIView *tableHeaderView;
@property (strong, nonatomic) UIImageView *drivingLicenseImageView;

@property (strong, nonatomic) NSDictionary *infoDic;
@property (strong, nonatomic) NSMutableArray *dataSource;

@end

@implementation ISDrivingCardResultViewController

- (instancetype)initWithDictionary:(NSDictionary *)info
{
    self = [super init];
    if (self != nil)
    {
        _infoDic = info;
    }
    return self;
}

- (IBAction)doneButtonDidClicked:(id)sender
{
    [self dismissViewControllerAnimated:YES completion:^
     {
         
     }];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    CGSize ScreenSize = [[UIScreen mainScreen] bounds].size;
    self.bgImageView.image = [UIImage imageNamed:@"bg"];
    
//    self.tableHeaderView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, ScreenSize.width, 174)];
    self.tableHeaderView.backgroundColor = UIColorFromRGB(0x13334A);
    
    self.titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 34, ScreenSize.width, 20)];
    self.titleLabel.textColor = [UIColor whiteColor];
    self.titleLabel.textAlignment = NSTextAlignmentCenter;
    [self.tableHeaderView addSubview:self.titleLabel];
    
    self.drivingLicenseImageView = [[UIImageView alloc] initWithFrame:CGRectMake(0, 64, ScreenSize.width, 300-64)];
    self.drivingLicenseImageView.contentMode = UIViewContentModeScaleAspectFit;
    [self.tableHeaderView addSubview:self.drivingLicenseImageView];
    
//    self.tableView.tableHeaderView = self.tableHeaderView;
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    self.tableView.backgroundColor = [UIColor clearColor];
    
    [self.doneButton setBackgroundColor:UIColorFromRGB(0x18B8F5)];
    self.doneButton.layer.cornerRadius = 4.0f;
    [self setupDataSource];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)setupDataSource
{
    CGSize screenSize = [[UIScreen mainScreen] bounds].size;
    {
        UIImage *drivingLicenseImage = [self.infoDic valueForKey:kOpenSDKCardResultTypeImage];
        self.drivingLicenseImageView.image = drivingLicenseImage;
        CGFloat imageHeight = (screenSize.width-20)/drivingLicenseImage.size.width*drivingLicenseImage.size.height;
        self.drivingLicenseImageView.frame = CGRectMake(10, 64, screenSize.width-20, imageHeight);
//        self.tableHeaderView.frame = CGRectMake(0, 0, screenSize.width, CGRectGetMaxY(self.drivingLicenseImageView.frame)+20);
        for (NSLayoutConstraint* constraint in self.tableHeaderView.constraints)
        {
            if (constraint.firstAttribute == NSLayoutAttributeHeight)
            {
                constraint.constant = CGRectGetMaxY(self.drivingLicenseImageView.frame)+10;
            }
        }
    }
    
    self.titleLabel.text = NSLocalizedString(@"驾驶证识别", @"驾驶证识别");
    [self.doneButton setTitle:NSLocalizedString(@"确定", @"确定") forState:UIControlStateNormal];
    
    self.dataSource = [NSMutableArray array];
    
    NSDictionary *itemInfo = [self.infoDic valueForKey:kOpenSDKCardResultTypeCardItemInfo];
    
    {
        NSString *drivingCardID = [itemInfo valueForKey:kDrivingCardItemIDNumber];
        if (drivingCardID) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"ID number:", @"DrivingCard number:");
            item.resultText = drivingCardID;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *drivingCardName = [itemInfo valueForKey:kDrivingCardItemName];
        if (drivingCardName) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"Name:", @"Name:");
            item.resultText = drivingCardName;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *sex = [itemInfo valueForKey:kDrivingCardItemSex];
        if (sex) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"Sex:", @"Sex:");
            item.resultText = sex;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *nation = [itemInfo valueForKey:kDrivingCardItemNationality];
        if (nation) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"Nation:", @"Nation:");
            item.resultText = nation;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *address = [itemInfo valueForKey:kDrivingCardItemAddress];
        if (address) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"Address:", @"Address:");
            item.resultText = address;
            item.numberOfline = 2;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *birthDay = [itemInfo valueForKey:kDrivingCardItemBirthDay];
        if (birthDay) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"BirthDay:", @"BirthDay:");
            item.resultText = birthDay;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *issueDate = [itemInfo valueForKey:kDrivingCardItemIssueDate];
        if (issueDate) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"IssueDate:", @"IssueDate:");
            item.resultText = issueDate;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *driveType = [itemInfo valueForKey:kDrivingCardItemDriveType];
        if (driveType) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"DriveType:", @"DriveType:");
            item.resultText = driveType;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *drivingCardID = [itemInfo valueForKey:kDrivingCardItemValidFrom];
        if (drivingCardID) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"ValidFrom:", @"ValidFrom:");
            item.resultText = drivingCardID;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *drivingCardID = [itemInfo valueForKey:kDrivingCardItemValidFor];
        if (drivingCardID) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"ExpireTime:", @"ExpireTime:");
            item.resultText = drivingCardID;
            [self.dataSource addObject:item];
        }
    }
    
    {
        NSString *drivingCardID = [itemInfo valueForKey:kDrivingCardItemValidity];
        if (drivingCardID) {
            ISDrivingCardResultItem *item = [[ISDrivingCardResultItem alloc] init];
            item.typeText = NSLocalizedString(@"ValidFor:", @"ValidFor:");
            item.resultText = drivingCardID;
            [self.dataSource addObject:item];
        }
    }
}

#pragma mark - UITableViewDataSource & UITableViewDelegate

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString * const ISDrivingLicenseResultTableViewCellIdentifier = @"ISDrivingLicenseResultTableViewCellIdentifier";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:ISDrivingLicenseResultTableViewCellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:ISDrivingLicenseResultTableViewCellIdentifier];
        cell.backgroundColor = [UIColor clearColor];
        cell.contentView.backgroundColor = [UIColor clearColor];
        cell.textLabel.textColor = UIColorFromRGB(0xE1E1E1);
        cell.detailTextLabel.textColor = UIColorFromRGB(0xFFFFFF);
        cell.detailTextLabel.textAlignment = NSTextAlignmentRight;
        cell.detailTextLabel.adjustsFontSizeToFitWidth = YES;
        cell.detailTextLabel.clipsToBounds = YES;
        cell.detailTextLabel.minimumScaleFactor = 0.5f;
    }
    
    if (indexPath.row < self.dataSource.count) {
        NSObject *data = self.dataSource[indexPath.row];
        if ([data isKindOfClass:[NSString class]]) {
            cell.textLabel.text = (NSString *)data;
        } else if ([data isKindOfClass:[ISDrivingCardResultItem class]]) {
            ISDrivingCardResultItem *item = (ISDrivingCardResultItem*)data;
            cell.detailTextLabel.numberOfLines = item.numberOfline;
//            cell.detailTextLabel.lineBreakMode = NSLineBreakByWordWrapping;
            cell.textLabel.text = item.typeText;
            cell.detailTextLabel.text = item.resultText;
        }
    }
    
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
//    NSUInteger row = indexPath.row;
//    if (row < self.dataSource.count) {
//        ISDrivingCardResultItem *item = self.dataSource[row];
//        if (item.numberOfline <= 1) {
//            return 44.0;
//        }
//        else
//        {
//            return 44.0 + (item.numberOfline -1) * 30;
//        }
//    }
    return 44.0;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}


- (UIImage *) croppedImage:(UIImage*)image withRect: (CGRect) bounds
{
    CGImageRef imageRef = CGImageCreateWithImageInRect([image CGImage], bounds);
    UIImage *croppedImage = [UIImage imageWithCGImage:imageRef];
    CGImageRelease(imageRef);
    return croppedImage;
}

@end
